==> zio-aws-codecommit_3-5.17.157.2-sources.jar: zio/aws/codecommit/model/BatchDescribeMergeConflictsRequest.scala <==
package zio.aws.codecommit.model
import zio.aws.codecommit.model.primitives.{
  CommitName,
  NextToken,
  RepositoryName,
  MaxResults,
  Path
}
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class BatchDescribeMergeConflictsRequest(
    repositoryName: RepositoryName,
    destinationCommitSpecifier: CommitName,
    sourceCommitSpecifier: CommitName,
    mergeOption: zio.aws.codecommit.model.MergeOptionTypeEnum,
    maxMergeHunks: Option[MaxResults] = None,
    maxConflictFiles: Option[MaxResults] = None,
    filePaths: Option[Iterable[Path]] = None,
    conflictDetailLevel: Option[
      zio.aws.codecommit.model.ConflictDetailLevelTypeEnum
    ] = None,
    conflictResolutionStrategy: Option[
      zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum
    ] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest = {
    import BatchDescribeMergeConflictsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest
      .builder()
      .repositoryName(RepositoryName.unwrap(repositoryName): java.lang.String)
      .destinationCommitSpecifier(
        CommitName.unwrap(destinationCommitSpecifier): java.lang.String
      )
      .sourceCommitSpecifier(
        CommitName.unwrap(sourceCommitSpecifier): java.lang.String
      )
      .mergeOption(mergeOption.unwrap)
      .optionallyWith(
        maxMergeHunks.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxMergeHunks)
      .optionallyWith(
        maxConflictFiles.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxConflictFiles)
      .optionallyWith(
        filePaths.map(value =>
          value.map { item =>
            Path.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.filePaths)
      .optionallyWith(conflictDetailLevel.map(value => value.unwrap))(
        _.conflictDetailLevel
      )
      .optionallyWith(conflictResolutionStrategy.map(value => value.unwrap))(
        _.conflictResolutionStrategy
      )
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest.ReadOnly =
    zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest
      .wrap(buildAwsValue())
}
object BatchDescribeMergeConflictsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest =
      zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest(
        repositoryName,
        destinationCommitSpecifier,
        sourceCommitSpecifier,
        mergeOption,
        maxMergeHunks.map(value => value),
        maxConflictFiles.map(value => value),
        filePaths.map(value => value),
        conflictDetailLevel.map(value => value),
        conflictResolutionStrategy.map(value => value),
        nextToken.map(value => value)
      )
    def repositoryName: RepositoryName
    def destinationCommitSpecifier: CommitName
    def sourceCommitSpecifier: CommitName
    def mergeOption: zio.aws.codecommit.model.MergeOptionTypeEnum
    def maxMergeHunks: Option[MaxResults]
    def maxConflictFiles: Option[MaxResults]
    def filePaths: Option[List[Path]]
    def conflictDetailLevel
        : Option[zio.aws.codecommit.model.ConflictDetailLevelTypeEnum]
    def conflictResolutionStrategy
        : Option[zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum]
    def nextToken: Option[NextToken]
    def getRepositoryName: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repositoryName)
    def getDestinationCommitSpecifier: ZIO[Any, Nothing, CommitName] =
      ZIO.succeed(destinationCommitSpecifier)
    def getSourceCommitSpecifier: ZIO[Any, Nothing, CommitName] =
      ZIO.succeed(sourceCommitSpecifier)
    def getMergeOption
        : ZIO[Any, Nothing, zio.aws.codecommit.model.MergeOptionTypeEnum] =
      ZIO.succeed(mergeOption)
    def getMaxMergeHunks: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxMergeHunks", maxMergeHunks)
    def getMaxConflictFiles: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxConflictFiles", maxConflictFiles)
    def getFilePaths: ZIO[Any, AwsError, List[Path]] =
      AwsError.unwrapOptionField("filePaths", filePaths)
    def getConflictDetailLevel: ZIO[
      Any,
      AwsError,
      zio.aws.codecommit.model.ConflictDetailLevelTypeEnum
    ] = AwsError.unwrapOptionField("conflictDetailLevel", conflictDetailLevel)
    def getConflictResolutionStrategy: ZIO[
      Any,
      AwsError,
      zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum
    ] = AwsError.unwrapOptionField(
      "conflictResolutionStrategy",
      conflictResolutionStrategy
    )
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest
  ) extends zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest.ReadOnly {
    override val repositoryName: RepositoryName =
      zio.aws.codecommit.model.primitives.RepositoryName(impl.repositoryName())
    override val destinationCommitSpecifier: CommitName =
      zio.aws.codecommit.model.primitives
        .CommitName(impl.destinationCommitSpecifier())
    override val sourceCommitSpecifier: CommitName =
      zio.aws.codecommit.model.primitives
        .CommitName(impl.sourceCommitSpecifier())
    override val mergeOption: zio.aws.codecommit.model.MergeOptionTypeEnum =
      zio.aws.codecommit.model.MergeOptionTypeEnum.wrap(impl.mergeOption())
    override val maxMergeHunks: Option[MaxResults] = scala
      .Option(impl.maxMergeHunks())
      .map(value => zio.aws.codecommit.model.primitives.MaxResults(value))
    override val maxConflictFiles: Option[MaxResults] = scala
      .Option(impl.maxConflictFiles())
      .map(value => zio.aws.codecommit.model.primitives.MaxResults(value))
    override val filePaths: Option[List[Path]] = scala
      .Option(impl.filePaths())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codecommit.model.primitives.Path(item)
        }.toList
      )
    override val conflictDetailLevel
        : Option[zio.aws.codecommit.model.ConflictDetailLevelTypeEnum] = scala
      .Option(impl.conflictDetailLevel())
      .map(value =>
        zio.aws.codecommit.model.ConflictDetailLevelTypeEnum.wrap(value)
      )
    override val conflictResolutionStrategy
        : Option[zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum] =
      scala
        .Option(impl.conflictResolutionStrategy())
        .map(value =>
          zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum
            .wrap(value)
        )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.codecommit.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest
  ): zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codecommit_3-5.19.33.1-sources.jar: zio/aws/codecommit/model/BatchDescribeMergeConflictsRequest.scala <==
package zio.aws.codecommit.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import zio.aws.codecommit.model.primitives.{
  CommitName,
  NextToken,
  RepositoryName,
  MaxResults,
  Path
}
import scala.jdk.CollectionConverters.*
final case class BatchDescribeMergeConflictsRequest(
    repositoryName: RepositoryName,
    destinationCommitSpecifier: CommitName,
    sourceCommitSpecifier: CommitName,
    mergeOption: zio.aws.codecommit.model.MergeOptionTypeEnum,
    maxMergeHunks: Optional[MaxResults] = Optional.Absent,
    maxConflictFiles: Optional[MaxResults] = Optional.Absent,
    filePaths: Optional[Iterable[Path]] = Optional.Absent,
    conflictDetailLevel: Optional[
      zio.aws.codecommit.model.ConflictDetailLevelTypeEnum
    ] = Optional.Absent,
    conflictResolutionStrategy: Optional[
      zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest = {
    import BatchDescribeMergeConflictsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest
      .builder()
      .repositoryName(RepositoryName.unwrap(repositoryName): java.lang.String)
      .destinationCommitSpecifier(
        CommitName.unwrap(destinationCommitSpecifier): java.lang.String
      )
      .sourceCommitSpecifier(
        CommitName.unwrap(sourceCommitSpecifier): java.lang.String
      )
      .mergeOption(mergeOption.unwrap)
      .optionallyWith(
        maxMergeHunks.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxMergeHunks)
      .optionallyWith(
        maxConflictFiles.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxConflictFiles)
      .optionallyWith(
        filePaths.map(value =>
          value.map { item =>
            Path.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.filePaths)
      .optionallyWith(conflictDetailLevel.map(value => value.unwrap))(
        _.conflictDetailLevel
      )
      .optionallyWith(conflictResolutionStrategy.map(value => value.unwrap))(
        _.conflictResolutionStrategy
      )
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest.ReadOnly =
    zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest
      .wrap(buildAwsValue())
}
object BatchDescribeMergeConflictsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest =
      zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest(
        repositoryName,
        destinationCommitSpecifier,
        sourceCommitSpecifier,
        mergeOption,
        maxMergeHunks.map(value => value),
        maxConflictFiles.map(value => value),
        filePaths.map(value => value),
        conflictDetailLevel.map(value => value),
        conflictResolutionStrategy.map(value => value),
        nextToken.map(value => value)
      )
    def repositoryName: RepositoryName
    def destinationCommitSpecifier: CommitName
    def sourceCommitSpecifier: CommitName
    def mergeOption: zio.aws.codecommit.model.MergeOptionTypeEnum
    def maxMergeHunks: Optional[MaxResults]
    def maxConflictFiles: Optional[MaxResults]
    def filePaths: Optional[List[Path]]
    def conflictDetailLevel
        : Optional[zio.aws.codecommit.model.ConflictDetailLevelTypeEnum]
    def conflictResolutionStrategy
        : Optional[zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum]
    def nextToken: Optional[NextToken]
    def getRepositoryName: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repositoryName)
    def getDestinationCommitSpecifier: ZIO[Any, Nothing, CommitName] =
      ZIO.succeed(destinationCommitSpecifier)
    def getSourceCommitSpecifier: ZIO[Any, Nothing, CommitName] =
      ZIO.succeed(sourceCommitSpecifier)
    def getMergeOption
        : ZIO[Any, Nothing, zio.aws.codecommit.model.MergeOptionTypeEnum] =
      ZIO.succeed(mergeOption)
    def getMaxMergeHunks: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxMergeHunks", maxMergeHunks)
    def getMaxConflictFiles: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxConflictFiles", maxConflictFiles)
    def getFilePaths: ZIO[Any, AwsError, List[Path]] =
      AwsError.unwrapOptionField("filePaths", filePaths)
    def getConflictDetailLevel: ZIO[
      Any,
      AwsError,
      zio.aws.codecommit.model.ConflictDetailLevelTypeEnum
    ] = AwsError.unwrapOptionField("conflictDetailLevel", conflictDetailLevel)
    def getConflictResolutionStrategy: ZIO[
      Any,
      AwsError,
      zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum
    ] = AwsError.unwrapOptionField(
      "conflictResolutionStrategy",
      conflictResolutionStrategy
    )
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest
  ) extends zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest.ReadOnly {
    override val repositoryName: RepositoryName =
      zio.aws.codecommit.model.primitives.RepositoryName(impl.repositoryName())
    override val destinationCommitSpecifier: CommitName =
      zio.aws.codecommit.model.primitives
        .CommitName(impl.destinationCommitSpecifier())
    override val sourceCommitSpecifier: CommitName =
      zio.aws.codecommit.model.primitives
        .CommitName(impl.sourceCommitSpecifier())
    override val mergeOption: zio.aws.codecommit.model.MergeOptionTypeEnum =
      zio.aws.codecommit.model.MergeOptionTypeEnum.wrap(impl.mergeOption())
    override val maxMergeHunks: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxMergeHunks())
      .map(value => zio.aws.codecommit.model.primitives.MaxResults(value))
    override val maxConflictFiles: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxConflictFiles())
      .map(value => zio.aws.codecommit.model.primitives.MaxResults(value))
    override val filePaths: Optional[List[Path]] = zio.aws.core.internal
      .optionalFromNullable(impl.filePaths())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codecommit.model.primitives.Path(item)
        }.toList
      )
    override val conflictDetailLevel
        : Optional[zio.aws.codecommit.model.ConflictDetailLevelTypeEnum] =
      zio.aws.core.internal
        .optionalFromNullable(impl.conflictDetailLevel())
        .map(value =>
          zio.aws.codecommit.model.ConflictDetailLevelTypeEnum.wrap(value)
        )
    override val conflictResolutionStrategy: Optional[
      zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.conflictResolutionStrategy())
      .map(value =>
        zio.aws.codecommit.model.ConflictResolutionStrategyTypeEnum.wrap(value)
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.codecommit.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.BatchDescribeMergeConflictsRequest
  ): zio.aws.codecommit.model.BatchDescribeMergeConflictsRequest.ReadOnly =
    new Wrapper(impl)
}
